# The RelationalAI Python Library

The Python library for building and querying knowledge graphs with RelationalAI.

This library is currently for internal users only. Public documentation is coming soon.
